abacusai.database_connector_schema — AbacusAI documentation

# abacusai.database_connector_schema

## Classes

`DatabaseConnectorSchema` | A schema description for a table from a database connector

## Module Contents

class abacusai.database_connector_schema.DatabaseConnectorSchema(client, tableName=None, columns={})

  Bases: `abacusai.return_class.AbstractApiClass`

  A schema description for a table from a database connector

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - tableName (str) – The unique name of the table.

    - columns (DatabaseConnectorColumn) – List of columns in the table.

  table_name
  columns
  deprecated_keys
  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict